==> dde-network-core_1.0.61.orig.tar.xz: dde-network-core-1.0.61/dock-network-plugin/translations/dock-network-plugin_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>ھەمبەھىر نۇقتىسى</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>كېلىشىم</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>بىخەتەرلىك تۈرى</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>دولقۇن بۆلىكى</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>قانال</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>ئۇلىنىش ئېغىزى</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>تور قەۋىتى</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>شەخسىي DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>قوشۇمچە</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>تېزلىكى</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>ئۈسكۈنە ئىشلىتىش چەكلەندى </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>تورغا ئۇلاندى،ئەمما تورنى زىيارەت قىلالمىدى</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>ئۇلانمىدى</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>تور سىمى ئۇلانمىغان </translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>ئۇلىنىۋاتىدۇ</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>دەلىللەۋاتىدۇ</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP ئادرېسىغا ئېرىشىش </translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>ئۇلاندى</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>ئۈزۈلدى </translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ئادرېس توقۇنۇشۇپ قالدى</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>ئادرېسىغا ئېرىشىۋاتىدۇ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>سىملىق تور</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>سىملىق تور%1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>سىمسىز تور</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>سىمسىز تور%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>ئۈسكۈنە ئىشلىتىش چەكلەندى </translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>تور سىمى ئۇلانمىغان </translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>ئۇلانمىدى</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>ئۇلىنىۋاتىدۇ</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>تورغا ئۇلاندى،ئەمما تورنى زىيارەت قىلالمىدى</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>ئۇلىنىش مەغلۇپ بولدى</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ئادرېس توقۇنۇشۇپ قالدى</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>سىملىق تورنى تاقاش</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>سىملىق تورنى ئېچىش</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>سىمسىز تورنى تاقاش</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>سىمسىز تورنى ئېچىش</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>تورنى تاقاش</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>تورنى قوزغىتىش </translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>تور تەڭشىكى </translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.7.orig.tar.xz: dde-network-core-1.1.7/dock-network-plugin/translations/dock-network-plugin_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>سىمسىز تور</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>سىملىق تور</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>يوشۇرۇن تورغا ئۇلاش</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>پارولنى كىرگۈزۈڭ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>ئۇلاش</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>تور نامىنى كىرگۈزۈڭ（SSID）</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>ھەمبەھىر نۇقتىسى</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>كېلىشىم</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>بىخەتەرلىك تۈرى</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>قانال</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>دولقۇن بۆلىكى</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>ئۇلىنىش ئېغىزى</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>تور قەۋىتى</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>تور قانىلى</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>شەخسىي DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>قوشۇمچە</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>تېزلىكى</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>ئۈسكۈنە ئىشلىتىش چەكلەندى </translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>تورغا ئۇلاندى،ئەمما تورنى زىيارەت قىلالمىدى</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>ئۇلانمىدى</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>تور سىمى ئۇلانمىغان </translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>ئۇلىنىۋاتىدۇ</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>دەلىللەۋاتىدۇ</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP ئادرېسىغا ئېرىشىش </translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>ئۇلاندى</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>ئۈزۈلدى </translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ئادرېس توقۇنۇشۇپ قالدى</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>مەغلۇب بولدى</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>ئادرېسىغا ئېرىشىۋاتىدۇ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>سىملىق تور</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>سىملىق تور%1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>سىمسىز تور</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>سىمسىز تور%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>ئۈسكۈنە ئىشلىتىش چەكلەندى </translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>تور سىمى ئۇلانمىغان </translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>ئۇلانمىدى</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>ئۇلىنىۋاتىدۇ</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>تورغا ئۇلاندى،ئەمما تورنى زىيارەت قىلالمىدى</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>ئۇلىنىش مەغلۇپ بولدى</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP ئادرېس توقۇنۇشۇپ قالدى</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>سىملىق تورنى تاقاش</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>سىملىق تورنى ئېچىش</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>سىمسىز تورنى تاقاش</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>سىمسىز تورنى ئېچىش</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>تورنى تاقاش</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>تورنى قوزغىتىش </translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>تور تەڭشىكى </translation>
    </message>
</context>
</TS>
